@@ -2,7 +2,7 @@
 
 set -eu
 
-DEST="$(dirname $0)/../playbooks/collections"
+DEST="$(dirname $0)/../.tox/linters/collections"
 SOURCE="${ANSIBLE_COLLECTION_SOURCE_PATH:-../ansible-collections-openstack}"
 
 if [ ! -d "$SOURCE" ]; then
@@ -16,10 +16,10 @@ rm -f "$DEST/ansible_collections/openstack/cloud"
 
 ln -s "$(realpath $SOURCE)" "$DEST/ansible_collections/openstack/cloud"
 
-export ANSIBLE_COLLECTIONS_PATHS="$DEST"
+export ANSIBLE_COLLECTIONS_PATHS="$(realpath $DEST)"
 export ANSIBLE_LIBRARY="$(dirname $0)/../playbooks/library"
 
 find playbooks -maxdepth 1 -type f -regex '.*.ya?ml' -print0 | \
-    xargs -t -n1 -0 ansible-lint -vv --nocolor
+    xargs -t -n1 -0 ansible-lint -v --nocolor
 find playbooks/roles -maxdepth 1 -mindepth 1 -type d -printf "%p/\n" | \
-    xargs -t -n1 ansible-lint -vv --nocolor
+    xargs -t -n1 ansible-lint -v --nocolor
